Drivers should return -ENOTTY ("Inappropriate I/O control operation")
when an ioctl isn't supported, while -EINVAL is used for invalid
arguments.

Fix up the TIOCMGET, TIOCMSET and TIOCGICOUNT helpers which returned
-EINVAL when a tty driver did not implement the corresponding
operations.

Note that the TIOCMGET and TIOCMSET helpers predate git and do not get a
corresponding Fixes tag below.

Fixes: d281da7ff6f7 ("tty: Make tiocgicount a handler")
Signed-off-by: Johan Hovold <jo...@kernel.org>
---
 drivers/tty/tty_io.c       | 10 +++++-----
 include/linux/tty_driver.h |  2 +-
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/include/linux/tty_driver.h b/include/linux/tty_driver.h
index 61c3372d3f32..2f719b471d52 100644
--- a/include/linux/tty_driver.h
+++ b/include/linux/tty_driver.h
@@ -228,7 +228,7 @@
  *
  *     Called when the device receives a TIOCGICOUNT ioctl. Passed a kernel
  *     structure to complete. This method is optional and will only be called
- *     if provided (otherwise EINVAL will be returned).
+ *     if provided (otherwise ENOTTY will be returned).
  */
 
 #include <linux/export.h>
diff --git a/drivers/tty/tty_io.c b/drivers/tty/tty_io.c
index ebcde1f96adb..7738514a15fe 100644
--- a/drivers/tty/tty_io.c
+++ b/drivers/tty/tty_io.c
@@ -2529,14 +2529,14 @@ static int send_break(struct tty_struct *tty, unsigned 
int duration)
  *     @p: pointer to result
  *
  *     Obtain the modem status bits from the tty driver if the feature
  *     is supported. Return -EINVAL if it is not available.
  *
  *     Locking: none (up to the driver)
  */
 
 static int tty_tiocmget(struct tty_struct *tty, int __user *p)
 {
-       int retval = -EINVAL;
+       int retval = -ENOTTY;
 
        if (tty->ops->tiocmget) {
                retval = tty->ops->tiocmget(tty);
@@ -2554,7 +2554,7 @@ static int tty_tiocmget(struct tty_struct *tty, int 
__user *p)
  *     @p: pointer to desired bits
  *
  *     Set the modem status bits from the tty driver if the feature
  *     is supported. Return -EINVAL if it is not available.
  *
  *     Locking: none (up to the driver)
  */
@@ -2566,7 +2566,7 @@ static int tty_tiocmset(struct tty_struct *tty, unsigned 
int cmd,
        unsigned int set, clear, val;
 
        if (tty->ops->tiocmset == NULL)
-               return -EINVAL;
+               return -ENOTTY;
 
        retval = get_user(val, p);
        if (retval)
@@ -2606,7 +2606,7 @@ int tty_get_icount(struct tty_struct *tty,
        if (tty->ops->get_icount)
                return tty->ops->get_icount(tty, icount);
        else
-               return -EINVAL;
+               return -ENOTTY;
 }
 EXPORT_SYMBOL_GPL(tty_get_icount);
 
@@ -2529,14 +2529,14 @@ static int send_break(struct tty_struct *tty, unsigned 
  *
  *     Obtain the modem status bits from the tty driver if the feature
- *     is supported. Return -EINVAL if it is not available.
+ *     is supported. Return -ENOTTY if it is not available.
  *
  *     Locking: none (up to the driver)
@@ -2554,7 +2554,7 @@ static int tty_tiocmget(struct tty_struct *tty, int 
  *
  *     Set the modem status bits from the tty driver if the feature
- *     is supported. Return -EINVAL if it is not available.
+ *     is supported. Return -ENOTTY if it is not available.
  *
  *     Locking: none (up to the driver)
-- 
2.26.3

Reply via email to